@@ -83,7 +83,7 @@ function list_files($uid)
         
         echo $html;
     } else {
-        echo "<p class='shared_file_message ulicms_error'>" . "Es sind momentan keine Dateien für diesen Kunden freigegeben." . "</p>";
+        echo "<p class='shared_file_message ulicms-error'>" . "Es sind momentan keine Dateien für diesen Kunden freigegeben." . "</p>";
     }
     
     echo "<p><a href=\"?action=module_settings&module=kundenbereich\">[Zurück zur Kundenliste]</a></p>";
