@@ -1,5 +1,5 @@
 <?php
-if (containsModule(get_requested_pagename(), "kundenbereich")) {
+if (containsModule(get_slug(), "kundenbereich")) {
     if (! is_logged_in()) {
         $url = "admin/?go=" . urlencode(getCurrentURL());
         header("Location: " . $url);
