@@ -22,7 +22,7 @@ function kundenbereich_render()
             
             $html .= "</ol>";
         } else {
-            echo "<span class='shared_file_message ulicms_error'>" . "Es sind momentan keine Dateien für Sie freigegeben." . "</span>";
+            echo "<span class='shared_file_message ulicms-error'>" . "Es sind momentan keine Dateien für Sie freigegeben." . "</span>";
         }
     }
     
